@@ -21,7 +21,6 @@ XMP-RPC API
 """
 
 import datetime
-import decimal
 import logging
 import re
 import urllib2
@@ -86,6 +85,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `version` ()
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         Return lava server version. The version is a string, which is the
@@ -141,6 +144,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `put` (`content`, `content_filename`, `pathname`)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         Upload a bundle to the server.
@@ -198,6 +205,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `put` (`content`, `content_filename`, `pathname`)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         Upload a bundle to the server.  A variant on put_ex that returns the
@@ -258,6 +269,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `put_pending` (`content`, `pathname`, `group_name`)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         MultiNode internal call.
@@ -337,6 +352,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `put_group` (`content`, `content_filename`, `pathname`, `group_name`)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         MultiNode internal call.
@@ -441,6 +460,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `get` (`content_sha1`)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         Download a bundle from the server.
@@ -492,6 +515,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `streams` ()
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         List all bundle streams that the user has access to
@@ -551,6 +578,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `bundles` (`pathname`)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         List all bundles in a specified bundle stream
@@ -638,6 +669,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `get_test_names` ([`device_type`]])
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         Get the name of all the tests that have run on a particular device type.
@@ -668,6 +703,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `deserialize` (`content_sha1`)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         Deserialize bundle on the server
@@ -709,6 +748,10 @@ class DashboardAPI(ExposedAPI):
         ----
         `make_stream` (`pathname`, `name`)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
         Create a bundle stream with the specified pathname
@@ -827,6 +870,10 @@ class DashboardAPI(ExposedAPI):
 
           get_filter_results(filter_name, count=10, offset=0)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
 
@@ -883,6 +930,10 @@ class DashboardAPI(ExposedAPI):
 
           get_filter_results_since(filter_name, since=None)
 
+        Deprecated
+        ----------
+        This function will cease to operate when V1 is disabled.
+
         Description
         -----------
 
