@@ -1,13 +1,16 @@
+"""
+zmq_client.py script
+"""
+# pylint: disable=missing-docstring,no-member,unused-variable,too-few-public-methods
+# pylint: disable=invalid-name,unused-argument,no-self-use,wrong-import-order
 # START_CLIENT
 
 import argparse
 import yaml
-import logging
-import re
 import signal
-import time
 import zmq
-from zmq.utils.strtypes import b, u
+import xmlrpclib
+from urlparse import urlsplit
 
 
 FINISHED_JOB_STATUS = ["Complete", "Incomplete", "Canceled"]
@@ -17,7 +20,7 @@ class JobEndTimeoutError(Exception):
     """ Raise when the specified job does not finish in certain timeframe. """
 
 
-class Timeout():
+class Timeout(object):
     """ Timeout error class with ALARM signal. Accepts time in seconds. """
     class TimeoutError(Exception):
         pass
@@ -36,7 +39,7 @@ class Timeout():
         raise Timeout.TimeoutError()
 
 
-class JobListener():
+class JobListener(object):
 
     def __init__(self, url):
         self.context = zmq.Context.instance()
@@ -68,20 +71,42 @@ class JobListener():
                 "JobListener timed out after %s seconds." % timeout)
 
 
+def lookup_publisher(hostname):
+    """
+    Lookup the publisher details using XML-RPC
+    on the specified hostname.
+    """
+    xmlrpc_url = "http://%s/RPC2" % (hostname)
+    server = xmlrpclib.ServerProxy(xmlrpc_url)
+    socket = server.scheduler.get_publisher_event_socket()
+    port = urlsplit(socket).port
+    listener_url = 'tcp://%s:%s' % (hostname, port)
+    print("Using %s" % listener_url)
+    return listener_url
+
+
 def main():
-    # Parse the command line
+    """
+    Parse the command line
+    For simplicity, this script does not handle usernames
+    and tokens so needs a job ID. For support submitting
+    a test job as well as watching the events, use lava-tool.
+    """
     parser = argparse.ArgumentParser()
-    parser.add_argument("-p", "--publisher", default="tcp://127.0.0.1:5500",
-                        help="Publisher host and port")
     parser.add_argument("-j", "--job-id", type=int,
                         help="Job ID to wait for")
+
     parser.add_argument("-t", "--timeout", type=int,
                         help="Timeout in seconds")
+    parser.add_argument("--hostname", help="hostname of the instance")
 
     options = parser.parse_args()
 
-    listener = JobListener(options.publisher)
+    publisher = lookup_publisher(options.hostname)
+
+    listener = JobListener(publisher)
     print listener.wait_for_job_end(options.job_id, options.timeout)
+    print('\n')
 
 
 if __name__ == '__main__':
