@@ -16,6 +16,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Lava Server.  If not, see <http://www.gnu.org/licenses/>.
 
+# pylint: disable=no-member,too-many-locals,too-many-nested-blocks,
+# pylint: disable=too-many-return-statements,ungrouped-imports
 import os
 import yaml
 import urllib
@@ -23,6 +25,7 @@ import logging
 import django
 import decimal
 from django.db import transaction
+from collections import OrderedDict  # pylint: disable=unused-import
 from lava_results_app.models import (
     TestSuite,
     TestSet,
@@ -31,9 +34,9 @@ from lava_results_app.models import (
     ActionData,
     MetaType,
 )
+from lava_results_app.utils import debian_package_version
 from django.core.exceptions import MultipleObjectsReturned
 from lava_dispatcher.pipeline.action import Timeout
-# pylint: disable=no-member,too-many-locals,too-many-nested-blocks
 
 if django.VERSION > (1, 10):
     from django.urls.exceptions import NoReverseMatch
@@ -76,14 +79,31 @@ def append_failure_comment(job, msg):
 
 
 def create_metadata_store(results, job, level):
+    """
+    Uses the OrderedDict import to correctly handle
+    the yaml.load
+    """
     if 'extra' not in results:
         return None
+    logger = logging.getLogger('dispatcher-master')
     stub = "%s-%s-%s.yaml" % (results['definition'], results['case'], level)
     meta_filename = os.path.join(job.output_dir, 'metadata', stub)
     if not os.path.exists(os.path.dirname(meta_filename)):
-        os.mkdir(os.path.dirname(meta_filename))
-    with open(meta_filename, 'a') as extra_store:
-        yaml.dump(results['extra'], extra_store)
+        os.makedirs(os.path.dirname(meta_filename), mode=0o755)
+    if os.path.exists(meta_filename):
+        with open(meta_filename, 'r') as existing_store:
+            data = yaml.load(existing_store)
+        data.update(results['extra'])
+    else:
+        data = results['extra']
+    try:
+        with open(meta_filename, 'w') as extra_store:
+            yaml.dump(data, extra_store)
+    except (OSError, IOError) as exc:  # LAVA-847
+        msg = "[%d] Unable to create metadata store: %s" % (job.id, exc)
+        logger.error(msg)
+        append_failure_comment(job, msg)
+        return None
     return meta_filename
 
 
@@ -120,14 +140,8 @@ def map_scanned_results(results, job, meta_filename):  # pylint: disable=too-man
         suite.save()
     testset = _check_for_testset(results, suite)
 
-    name = results["case"]
-    try:
-        reverse('lava.results.testcase', args=[job.id, suite.name, name])
-    except NoReverseMatch:
-        append_failure_comment(
-            job,
-            "[%d] Unable to parse test case name as URL %s in suite %s" % (job.id, name, suite.name))
-        return False
+    name = results["case"].strip()
+
     if suite.name == "lava":
         match_action = None
         if "level" in results:
@@ -151,24 +165,14 @@ def map_scanned_results(results, job, meta_filename):  # pylint: disable=too-man
         if 'duration' in results:
             measurement = results['duration']
             units = 'seconds'
-        try:
-            # For lava test suite, the test (actions) can be seen two times.
-            case = TestCase.objects.get(name=name, suite=suite)
-            case.test_set = testset
-            case.metadata = yaml.dump(results)
-            case.result = result_val
-            case.measurement = measurement
-            case.units = units
-        except TestCase.DoesNotExist:
-            case = TestCase.objects.create(name=name,
-                                           suite=suite,
-                                           test_set=testset,
-                                           metadata=yaml.dump(results),
-                                           measurement=measurement,
-                                           units=units,
-                                           result=result_val)
+        case = TestCase.objects.create(name=name,
+                                       suite=suite,
+                                       test_set=testset,
+                                       metadata=yaml.dump(results),
+                                       measurement=measurement,
+                                       units=units,
+                                       result=result_val)
         with transaction.atomic():
-            case.save()
             if match_action:
                 match_action.testcase = case
                 match_action.save(update_fields=['testcase', 'duration', 'timeout'])
@@ -195,6 +199,7 @@ def map_scanned_results(results, job, meta_filename):  # pylint: disable=too-man
                 suite=suite,
                 test_set=testset,
                 result=TestCase.RESULT_MAP[result],
+                metadata=yaml.dump(results),
                 measurement=measurement,
                 units=units
             ).save()
@@ -215,6 +220,11 @@ def _get_job_metadata(data):  # pylint: disable=too-many-branches,too-many-neste
     if not isinstance(data, list):
         return None
     retval = {}
+    packaged = debian_package_version()
+    if packaged:
+        retval.update({
+            'lava-server-version': packaged
+        })
     for action in data:
         deploy = [reduce(dict.get, ['deploy'], action)]
         count = 0
@@ -399,8 +409,11 @@ def map_metadata(description, job):
     # Add metadata from job submission data.
     if "metadata" in submission_data:
         for key in submission_data["metadata"]:
-            testdata.attributes.create(name=key,
-                                       value=submission_data["metadata"][key])
+            value = submission_data["metadata"][key]
+            if not key or not value:
+                logger.warning('[%s] Missing element in job. %s: %s', job.id, key, value)
+                continue
+            testdata.attributes.create(name=key, value=value)
 
     walk_actions(description_data['pipeline'], testdata, submission_data)
     return True
@@ -414,7 +427,7 @@ def testcase_export_fields():
     return [
         'job', 'suite', 'result', 'measurement', 'unit',
         'duration', 'timeout',
-        'logged', 'level', 'metadata', 'url',
+        'logged', 'level', 'metadata', 'url', 'name', 'id'
     ]
 
 
@@ -453,5 +466,6 @@ def export_testcase(testcase):
         'level': str(level),
         'metadata': metadata,
         'url': str(testcase.get_absolute_url()),
+        'id': str(testcase.id)
     }
     return casedict
