@@ -437,13 +437,9 @@ class TestCase(models.Model, Queryable):
 
         return attribute
 
+    @models.permalink
     def get_absolute_url(self):
-        if self.test_set:
-            return urllib.quote("/results/%s/%s/%s/%s" % (
-                self.suite.job.id, self.suite.name, self.test_set.name, self.name))
-        else:
-            return urllib.quote("/results/%s/%s/%s" % (
-                self.suite.job.id, self.suite.name, self.name))
+        return ("lava.results.testcase", [self.id])
 
     def _get_value(self):
         if self.measurement:
@@ -576,13 +572,13 @@ class MetaType(models.Model):
         if not data:
             logger.debug('get_type_name: skipping %s' % section)
             return None
-        if level > len(definition['actions']) or section not in definition['actions'][level]:
+        if level >= len(definition['actions']) or section not in definition['actions'][level]:
             logger.warning('get_type_name: unrecognised level %s for section %s', level, section)
             return None
         data = definition['actions'][level][section]
         if section in MetaType.TYPE_MAP:
             section_type = MetaType.get_section_type(name, section)
-            if section_type:
+            if section_type and section_type in data:
                 retval = data[section_type]
             if isinstance(retval, list):
                 return section_type
@@ -1477,7 +1473,7 @@ class ChartQuery(models.Model):
     xaxis_attribute = models.CharField(
         blank=True,
         null=True,
-        max_length=20,
+        max_length=100,
         verbose_name='X-axis attribute')
 
     representation = models.CharField(
