@@ -154,9 +154,18 @@ class ResultsTable(LavaTable):
             )
 
     job_id = tables.Column(verbose_name='Job ID')
-    actions = tables.TemplateColumn(
-        template_name="lava_results_app/suite_actions_field.html")
+
+    actions = tables.TemplateColumn('''
+<div class="text-nowrap">
+  <a href="{{ record.job.results_link }}" class="btn btn-xs btn-success" title="View job results">
+    <span class="glyphicon glyphicon-signal"></span>
+  </a>
+  <a href="{{ record.job.get_absolute_url }}" class="btn btn-xs btn-info" title="View job details">
+    <span class="glyphicon glyphicon-chevron-left"></span>
+</a>
+</div>''')
     actions.orderable = False
+
     submitter = tables.Column(accessor='job.submitter')
     name = tables.Column(verbose_name='Test Suite')
     passes = tables.Column(accessor='job', verbose_name='Passes')
@@ -197,7 +206,7 @@ class SuiteTable(LavaTable):
     """
     def __init__(self, *args, **kwargs):
         super(SuiteTable, self).__init__(*args, **kwargs)
-        self.length = 10
+        self.length = 25
 
     name = tables.Column()
     test_set = tables.Column(verbose_name="Test Set")
@@ -214,15 +223,7 @@ class SuiteTable(LavaTable):
         )
 
     def render_result(self, record):  # pylint: disable=no-self-use
-        # Keep backward compatibility with the previous log format for V2
-        if record.metadata:
-            if record.result != TestCase.RESULT_UNKNOWN:
-                code = record.result_code
-            else:
-                code = 'pass' if 'success' in record.action_metadata else 'fail'
-        else:
-            code = record.result_code
-
+        code = record.result_code
         if code == 'pass':
             icon = 'ok'
         elif code == 'fail':
