@@ -3,6 +3,7 @@ import os
 import re
 import yaml
 import shutil
+import logging
 import decimal
 import django
 from django.core.exceptions import MultipleObjectsReturned
@@ -39,6 +40,12 @@ class TestMetaTypes(TestCaseWithFactory):
     """
     MetaType and ActionData generation
     """
+
+    def setUp(self):
+        super(TestMetaTypes, self).setUp()
+        logger = logging.getLogger('dispatcher-master')
+        logger.disabled = True
+
     def test_job(self):
         MetaType.objects.all().delete()
         TestJob.objects.all().delete()
@@ -46,11 +53,12 @@ class TestMetaTypes(TestCaseWithFactory):
             self.factory.make_job_yaml(), self.user)
         job_def = yaml.load(job.definition)
         job_ctx = job_def.get('context', {})
+        job_ctx.update({'no_kvm': True})  # override to allow unit tests on all types of systems
         device = Device.objects.get(hostname='fakeqemu1')
-        device_config = device.load_device_configuration(job_ctx, system=False)  # raw dict
+        device_config = device.load_configuration(job_ctx)  # raw dict
         parser = JobParser()
         obj = PipelineDevice(device_config, device.hostname)
-        pipeline_job = parser.parse(job.definition, obj, job.id, None, None, None, output_dir='/tmp')
+        pipeline_job = parser.parse(job.definition, obj, job.id, None, "", output_dir='/tmp')
         allow_missing_path(pipeline_job.pipeline.validate_actions, self,
                            'qemu-system-x86_64')
         pipeline = pipeline_job.describe()
@@ -82,6 +90,7 @@ class TestMetaTypes(TestCaseWithFactory):
             self.factory.make_job_yaml(), self.user)
         test_suite = TestSuite.objects.get_or_create(name='lava', job=job)[0]
         test_case = TestCase(
+            id=1,
             name='name',
             suite=test_suite,
             result=TestCase.RESULT_FAIL
@@ -124,15 +133,18 @@ class TestMetaTypes(TestCaseWithFactory):
         self.assertIsNotNone(matches)  # passes
         self.assertEqual(matches.group(0), test_dict['case'])
         suite, _ = TestSuite.objects.get_or_create(name=test_dict["definition"], job=job)
-        self.assertIsNotNone(reverse('lava.results.testcase', args=[job.id, suite.name, test_dict['case']]))
+        case, _ = TestCase.objects.get_or_create(suite=suite,
+                                                 name=test_dict['case'],
+                                                 result=TestCase.RESULT_PASS)
+        self.assertIsNotNone(reverse('lava.results.testcase', args=[case.id]))
+        self.assertIsNotNone(reverse('lava.results.testcase',
+                                     args=[job.id, suite.name, case.id]))
         self.assertTrue(map_scanned_results(test_dict, job, None))
         # now break the reverse pattern
-        test_dict['case'] = 'unit-test\r\n'
-        pattern = '-_a-zA-Z0-9.\\(\\)+'
+        test_dict['case'] = 'unit test'  # whitespace in the case name
         matches = re.search(pattern, test_dict['case'])
-        self.assertIsNone(matches)  # fails
+        self.assertIsNotNone(matches)
         self.assertRaises(NoReverseMatch, reverse, 'lava.results.testcase', args=[job.id, suite.name, test_dict['case']])
-        self.assertFalse(map_scanned_results(test_dict, job, None))
 
     def test_metastore(self):
         field = TestCase._meta.get_field('metadata')
@@ -174,11 +186,12 @@ class TestMetaTypes(TestCaseWithFactory):
             self.factory.make_job_yaml(), self.user)
         job_def = yaml.load(job.definition)
         job_ctx = job_def.get('context', {})
+        job_ctx.update({'no_kvm': True})  # override to allow unit tests on all types of systems
         device = Device.objects.get(hostname='fakeqemu1')
-        device_config = device.load_device_configuration(job_ctx, system=False)  # raw dict
+        device_config = device.load_configuration(job_ctx)  # raw dict
         parser = JobParser()
         obj = PipelineDevice(device_config, device.hostname)
-        pipeline_job = parser.parse(job.definition, obj, job.id, None, None, None, output_dir='/tmp')
+        pipeline_job = parser.parse(job.definition, obj, job.id, None, "", output_dir='/tmp')
         allow_missing_path(pipeline_job.pipeline.validate_actions, self,
                            'qemu-system-x86_64')
         pipeline = pipeline_job.describe()
@@ -199,6 +212,8 @@ class TestMetaTypes(TestCaseWithFactory):
                 continue
             testdata.attributes.create(name=key, value=value)
         retval = _get_job_metadata(pipeline['job']['actions'])
+        if 'lava-server-version' in retval:
+            del retval['lava-server-version']
         self.assertEqual(
             retval,
             {
@@ -224,11 +239,12 @@ class TestMetaTypes(TestCaseWithFactory):
         job = TestJob.from_yaml_and_user(yaml.dump(data), self.user)
         job_def = yaml.load(job.definition)
         job_ctx = job_def.get('context', {})
+        job_ctx.update({'no_kvm': True})  # override to allow unit tests on all types of systems
         device = Device.objects.get(hostname='fakeqemu1')
-        device_config = device.load_device_configuration(job_ctx, system=False)  # raw dict
+        device_config = device.load_configuration(job_ctx)  # raw dict
         parser = JobParser()
         obj = PipelineDevice(device_config, device.hostname)
-        pipeline_job = parser.parse(job.definition, obj, job.id, None, None, None, output_dir='/tmp')
+        pipeline_job = parser.parse(job.definition, obj, job.id, None, "", output_dir='/tmp')
         allow_missing_path(pipeline_job.pipeline.validate_actions, self,
                            'qemu-system-x86_64')
         pipeline = pipeline_job.describe()
@@ -256,11 +272,12 @@ class TestMetaTypes(TestCaseWithFactory):
         job = TestJob.from_yaml_and_user(data, self.user)
         job_def = yaml.load(job.definition)
         job_ctx = job_def.get('context', {})
+        job_ctx.update({'no_kvm': True})  # override to allow unit tests on all types of systems
         device = Device.objects.get(hostname='fakeqemu1')
-        device_config = device.load_device_configuration(job_ctx, system=False)  # raw dict
+        device_config = device.load_configuration(job_ctx)  # raw dict
         parser = JobParser()
         obj = PipelineDevice(device_config, device.hostname)
-        pipeline_job = parser.parse(job.definition, obj, job.id, None, None, None, output_dir='/tmp')
+        pipeline_job = parser.parse(job.definition, obj, job.id, None, "", output_dir='/tmp')
         allow_missing_path(pipeline_job.pipeline.validate_actions, self,
                            'qemu-system-x86_64')
         pipeline = pipeline_job.describe()
@@ -295,11 +312,12 @@ class TestMetaTypes(TestCaseWithFactory):
         job = TestJob.from_yaml_and_user(yaml.dump(data), self.user)
         job_def = yaml.load(job.definition)
         job_ctx = job_def.get('context', {})
+        job_ctx.update({'no_kvm': True})  # override to allow unit tests on all types of systems
         device = Device.objects.get(hostname='fakeqemu1')
-        device_config = device.load_device_configuration(job_ctx, system=False)  # raw dict
+        device_config = device.load_configuration(job_ctx)  # raw dict
         parser = JobParser()
         obj = PipelineDevice(device_config, device.hostname)
-        pipeline_job = parser.parse(job.definition, obj, job.id, None, None, None, output_dir='/tmp')
+        pipeline_job = parser.parse(job.definition, obj, job.id, None, "", output_dir='/tmp')
         allow_missing_path(pipeline_job.pipeline.validate_actions, self,
                            'qemu-system-x86_64')
         pipeline = pipeline_job.describe()
