@@ -9,8 +9,7 @@ from lava_results_app.models import (
 from lava_results_app.dbutils import map_scanned_results
 from lava_scheduler_app.models import (
     TestJob, Device,
-    DeviceType, DeviceDictionary,
-    JobPipeline,
+    DeviceType
 )
 from django_testscenarios.ubertest import TestCase as DjangoTestCase
 
@@ -39,7 +38,6 @@ class ModelFactory(object):
         # make sure the DB is in a clean state wrt devices and jobs
         Device.objects.all().delete()
         TestJob.objects.all().delete()
-        [item.delete() for item in DeviceDictionary.object_list()]
         User.objects.all().delete()
 
     def make_user(self):
@@ -58,14 +56,8 @@ class ModelFactory(object):
     def make_job_yaml(self, **kw):
         return yaml.safe_dump(self.make_job_data(**kw))
 
-    def make_fake_qemu_device(self, hostname='fakeqemu1'):  # pylint: disable=no-self-use
-        qemu = DeviceDictionary(hostname=hostname)
-        qemu.parameters = {'extends': 'qemu.jinja2', 'arch': 'amd64'}
-        qemu.save()
-
-    def make_device_type(self, name='qemu', health_check_job=None):
-        (device_type, created) = DeviceType.objects.get_or_create(
-            name=name, health_check_job=health_check_job)
+    def make_device_type(self, name='qemu'):
+        (device_type, created) = DeviceType.objects.get_or_create(name=name)
         if created:
             device_type.save()
         return device_type
@@ -78,7 +70,6 @@ class ModelFactory(object):
         if tags and type(tags) != list:
             tags = []
         device = Device(device_type=device_type, is_public=is_public, hostname=hostname, is_pipeline=True, **kw)
-        self.make_fake_qemu_device(hostname)
         if tags:
             device.tags = tags
         logging.debug("making a device of type %s %s %s with tags '%s'"
@@ -96,6 +87,8 @@ class TestCaseWithFactory(DjangoTestCase):
         self.device_type = self.factory.make_device_type()
         self.factory.make_device(device_type=self.device_type, hostname="fakeqemu1")
         self.user = self.factory.make_user()
+        logger = logging.getLogger('dispatcher-master')
+        logger.disabled = True
 
 
 class TestTestSuite(TestCaseWithFactory):
@@ -103,15 +96,6 @@ class TestTestSuite(TestCaseWithFactory):
     Test suite naming
     """
 
-    def test_result_store(self):
-        job = TestJob.from_yaml_and_user(
-            self.factory.make_job_yaml(), self.user)
-        store = JobPipeline.get(job.id)
-        self.assertIsNotNone(store)
-        self.assertIsInstance(store, JobPipeline)
-        self.assertIs(type(store.pipeline), dict)
-        self.factory.cleanup()
-
     def test_pipelinestore(self):
         job = TestJob.from_yaml_and_user(
             self.factory.make_job_yaml(), self.user)
@@ -125,7 +109,8 @@ class TestTestSuite(TestCaseWithFactory):
         for sample in result_samples:
             ret = map_scanned_results(results=sample, job=job, meta_filename=None)
             self.assertTrue(ret)
-        self.assertEqual(4, TestCase.objects.count())
+        # the duplicate smoke-tests-basic is allowed here as the lava test suite supports multiples
+        self.assertEqual(5, TestCase.objects.count())
         val = URLValidator()
         for testcase in TestCase.objects.all():
             self.assertIsNotNone(testcase.name)
