@@ -7,6 +7,9 @@ class LAVASchedulerConfig(AppConfig):
     verbose_name = "lava_scheduler_app"
 
     def ready(self):
+        # Import the checks
+        import lava_scheduler_app.checks
+
         # Only install signals when requested
         if settings.EVENT_NOTIFICATION:
             import lava_scheduler_app.signals
