@@ -18,7 +18,6 @@ from django.utils import timezone
 from linaro_django_xmlrpc.models import AuthToken
 from lava_scheduler_app.models import (
     Device,
-    DeviceDictionary,
     DevicesUnavailableException,
     DeviceType,
     is_deprecated_json,
@@ -27,6 +26,7 @@ from lava_scheduler_app.models import (
     TemporaryDevice,
     validate_job,
 )
+from lava_scheduler_app.schema import SubmissionException
 from lava_results_app.dbutils import map_metadata
 from lava_dispatcher.pipeline.device import PipelineDevice
 
@@ -36,28 +36,30 @@ from lava_dispatcher.pipeline.device import PipelineDevice
 def match_vlan_interface(device, job_def):
     if not isinstance(job_def, dict):
         raise RuntimeError("Invalid vlan interface data")
-    if 'protocols' not in job_def or 'lava-vland' not in job_def['protocols']:
+    if 'protocols' not in job_def or 'lava-vland' not in job_def['protocols'] or not device:
         return False
     interfaces = []
     logger = logging.getLogger('dispatcher-master')
-    device_dict = DeviceDictionary.get(device.hostname).to_dict()
-    if 'tags' not in device_dict['parameters']:
-        logger.error("%s has no tags in the device dictionary parameters", device.hostname)
+    device_dict = device.load_configuration()
+    if not device_dict or device_dict.get('parameters', {}).get('interfaces', None) is None:
         return False
+
     for vlan_name in job_def['protocols']['lava-vland']:
         tag_list = job_def['protocols']['lava-vland'][vlan_name]['tags']
-        for interface, tags in device_dict['parameters']['tags'].iteritems():
+        for interface in device_dict['parameters']['interfaces']:
+            tags = device_dict['parameters']['interfaces'][interface]['tags']
+            if not tags:
+                continue
             logger.info(
                 "Job requests %s for %s, device %s provides %s for %s",
                 tag_list, vlan_name, device.hostname, tags, interface)
-            # tags & job tags must equal job tags
-            # device therefore must support all job tags, not all job tags available on the device need to be specified
             if set(tags) & set(tag_list) == set(tag_list) and interface not in interfaces:
                 logger.info("Matched vlan %s to interface %s on %s", vlan_name, interface, device)
                 interfaces.append(interface)
                 # matched, do not check any further interfaces of this device for this vlan
                 break
-    logger.info("Matched: %s" % (len(interfaces) == len(job_def['protocols']['lava-vland'].keys())))
+
+    logger.info("Matched: %s", (len(interfaces) == len(job_def['protocols']['lava-vland'].keys())))
     return len(interfaces) == len(job_def['protocols']['lava-vland'].keys())
 
 
@@ -73,11 +75,7 @@ def initiate_health_check_job(device):
         logger.error("[%s] has been retired", device)
         return None
 
-    existing_health_check_job = device.get_existing_health_check_job()
-    if existing_health_check_job:
-        return existing_health_check_job
-
-    job_data = device.device_type.health_check_job
+    job_data = device.get_health_check()
     user = User.objects.get(username='lava-health')
     if not job_data:
         # This should never happen, it's a logic error.
@@ -95,7 +93,7 @@ def initiate_health_check_job(device):
             return None
     try:
         job = testjob_submission(job_data, user, check_device=device)
-    except DevicesUnavailableException as exc:
+    except (DevicesUnavailableException, SubmissionException) as exc:
         logger.error("[%s] failed to submit health check - %s", device.device_type.name, exc)
         return None
     return job
@@ -115,7 +113,10 @@ def submit_health_check_jobs():
         run_health_check = False
         if device.device_type.health_denominator == DeviceType.HEALTH_PER_JOB:
             time_denominator = False
-        if not device.device_type.health_check_job:
+
+        if device.device_type.disable_health_check:
+            run_health_check = False
+        elif not device.get_health_check():
             run_health_check = False
         elif device.health_status == Device.HEALTH_UNKNOWN:
             run_health_check = True
@@ -161,7 +162,7 @@ def submit_health_check_jobs():
                 pass
 
 
-def testjob_submission(job_definition, user, check_device=None):
+def testjob_submission(job_definition, user, check_device=None, original_job=None):
     """
     Single submission frontend for JSON or YAML
     :param job_definition: string of the job submission
@@ -208,7 +209,7 @@ def testjob_submission(job_definition, user, check_device=None):
     else:
         validate_job(job_definition)
         # returns a single job or a list (not a QuerySet) of job objects.
-        job = TestJob.from_yaml_and_user(job_definition, user)
+        job = TestJob.from_yaml_and_user(job_definition, user, original_job=original_job)
         if check_device and isinstance(check_device, Device) and not isinstance(job, list):
             # the slave must neither know nor care if this is a health check,
             # only the master cares and that has the database connection.
@@ -248,6 +249,10 @@ def check_device_and_job(job, device):
         logger.warning("Refusing to reserve %s for %s - current job is %s",
                        device, job, bad_job)
         return None
+    if job.is_pipeline and device.is_pipeline and not device.is_valid():
+        # check for invalid templates from local admin changes
+        logger.warning("[%d] Refusing to reserve for broken V2 device %s", job.id, device.hostname)
+        return None
     return device
 
 
@@ -298,6 +303,15 @@ def find_device_for_job(job, device_list):  # pylint: disable=too-many-branches
             if device.can_submit(job.submitter) and\
                     set(job.tags.all()) & set(device.tags.all()) == set(job.tags.all()):
                 device = check_device_and_job(job, device)
+                if not device:
+                    continue
+                if job.is_pipeline:
+                    job_dict = yaml.load(job.definition)
+                    if 'protocols' in job_dict and 'lava-vland' in job_dict['protocols']:
+                        logger.info("[%d] checking %s for vlan interface support", job.id, str(device.hostname))
+                        if not match_vlan_interface(device, job_dict):
+                            logger.info("%s does not match vland tags", str(device.hostname))
+                            continue
                 return device
     return None
 
@@ -519,15 +533,6 @@ def assign_jobs():
         device = find_device_for_job(job, devices)
         # slower steps as assignment happens less often than the checks
         if device:
-            if job.is_pipeline:
-                job_dict = yaml.load(job.definition)
-                if 'protocols' in job_dict and 'lava-vland' in job_dict['protocols']:
-                    logger.info("[%d] checking vlan interface support", job.id)
-                    if not match_vlan_interface(device, job_dict):
-                        logger.info("%s does not match vland tags", str(device.hostname))
-                        if device in devices:
-                            devices.remove(device)
-                        continue
             if not _validate_idle_device(job, device) and device in devices:
                 logger.debug("Removing %s from the list of available devices",
                              str(device.hostname))
@@ -671,9 +676,11 @@ def end_job(job, fail_msg=None, job_status=TestJob.COMPLETE):
         return
     msg = "Job %d has ended. Setting job status %s" % (job.id, TestJob.STATUS_CHOICES[job.status][1])
     device = handle_health(job)
-    # Transition device only if it's not in OFFLINE/ING mode
+    # Transition device only if it's not in OFFLINE mode
     # (by failed health check job which already transitions it)
-    if device.status not in [Device.OFFLINE, Device.OFFLINING]:
+    if device.status == Device.OFFLINING:
+        device.state_transition_to(Device.OFFLINE, message=msg, job=job, master=True)
+    elif device.status != Device.OFFLINE:
         device.state_transition_to(Device.IDLE, message=msg, job=job, master=True)
     device.current_job = None
     # Save the result
@@ -689,7 +696,12 @@ def cancel_job(job):
         return
     msg = "Job %d cancelled" % job.id
     device = handle_health(job)
-    device.state_transition_to(Device.IDLE, message=msg, job=job, master=True)
+    # Transition device only if it's not in OFFLINE mode
+    # (by failed health check job which already transitions it)
+    if device.status == Device.OFFLINING:
+        device.state_transition_to(Device.OFFLINE, message=msg, job=job, master=True)
+    elif device.status != Device.OFFLINE:
+        device.state_transition_to(Device.IDLE, message=msg, job=job, master=True)
     if device.current_job and device.current_job == job:
         device.current_job = None
     # Save the result
@@ -750,12 +762,11 @@ def select_device(job, dispatchers):  # pylint: disable=too-many-return-statemen
     job_def = yaml.load(job.definition)
     job_ctx = job_def.get('context', {})
     device = None
-    device_object = None
     if not job.dynamic_connection:
         device = job.actual_device
 
         try:
-            device_config = device.load_device_configuration(job_ctx)  # raw dict
+            device_config = device.load_configuration(job_ctx)  # raw dict
         except (jinja2.TemplateError, yaml.YAMLError, IOError) as exc:
             logger.error("[%d] jinja2 error: %s", job.id, exc)
             msg = "Administrative error. Unable to parse device configuration: '%s'" % exc
@@ -831,13 +842,13 @@ def device_type_summary(visible=None):
                 ),
                 busy=Sum(
                     Case(
-                        When(status__in=[Device.RUNNING, Device.RESERVED], then=1),
+                        When(status__in=[Device.RUNNING, Device.RESERVED, Device.OFFLINING], then=1),
                         default=0, output_field=IntegerField()
                     )
                 ),
                 offline=Sum(
                     Case(
-                        When(status__in=[Device.OFFLINE, Device.OFFLINING], then=1),
+                        When(status__in=[Device.OFFLINE], then=1),
                         default=0, output_field=IntegerField()
                     )
                 ),
@@ -847,3 +858,28 @@ def device_type_summary(visible=None):
                     )
                 ),).order_by('device_type')
     return devices
+
+
+def load_devicetype_template(device_type_name):
+    """
+    Loads the bare device-type template as a python dictionary object for
+    representation within the device_type templates.
+    No device-specific details are parsed - default values only, so some
+    parts of the dictionary may be unexpectedly empty. Not to be used when
+    rendering device configuration for a testjob.
+    :param device_type_name: DeviceType.name (string)
+    :param path: optional alternative path to templates
+    :return: None or a dictionary of the device type template.
+    """
+    path = os.path.dirname(Device.CONFIG_PATH)
+    type_loader = jinja2.FileSystemLoader([os.path.join(path, 'device-types')])
+    env = jinja2.Environment(
+        loader=jinja2.ChoiceLoader([type_loader]),
+        trim_blocks=True)
+    try:
+        template = env.get_template("%s.jinja2" % device_type_name)
+    except jinja2.TemplateNotFound:
+        return None
+    if not template:
+        return None
+    return yaml.load(template.render())
