@@ -1,50 +1,70 @@
 import re
+import urllib2
+import yaml
 from voluptuous import (
-    Schema, Required, All, Length,
-    Any, Invalid, Optional, MultipleInvalid
+    All,
+    Any,
+    Exclusive,
+    Invalid,
+    Length,
+    Match,
+    MultipleInvalid,
+    Optional,
+    Required,
+    Schema
 )
 
 
+INVALID_CHARACTER_ERROR_MSG = "Invalid character"
+INCLUDE_URL_TIMEOUT = 10
+
+
 class SubmissionException(UserWarning):
     """ Error raised if the submission is itself invalid. """
 
 
 def _timeout_schema():
     return Schema({
-        'days': int, 'hours': int, 'minutes': int, 'seconds': int
+        Exclusive('days', 'timeout_unit'): int,
+        Exclusive('hours', 'timeout_unit'): int,
+        Exclusive('minutes', 'timeout_unit'): int,
+        Exclusive('seconds', 'timeout_unit'): int
     })
 
 
 def _deploy_tftp_schema():
     return Schema({
         Required('to'): 'tftp',
+        Optional('timeout'): _timeout_schema(),
         Optional('kernel'): {Required('url'): str},
         Optional('ramdisk'): {Required('url'): str},
         Optional('nbdroot'): {Required('url'): str},
         Optional('nfsrootfs'): {Required('url'): str},
         Optional('dtb'): {Required('url'): str},
+        Optional('modules'): {Required('url'): str},
     }, extra=True)
 
 
 def _job_deploy_schema():
     return Schema({
         Required('to'): str,
-        Optional('timeouts'): _timeout_schema(),
+        Optional('timeout'): _timeout_schema(),
     }, extra=True)
 
 
 def _auto_login_schema():
     return Schema({
-        Optional('login_prompt'): str,
-        Optional('username'): str,
+        Required('login_prompt'): str,
+        Required('username'): str,
         Optional('password_prompt'): str,
-        Optional('password'): str
+        Optional('password'): str,
+        Optional('login_commands'): list,
     })
 
 
 def _simple_params():
     return Schema({
-        Any(str): str
+        Any(str): Any(str, bool)
     })
 
 
@@ -60,7 +80,7 @@ def _context_schema():
 def _job_boot_schema():
     return Schema({
         Required('method'): str,
-        Optional('timeouts'): _timeout_schema(),
+        Optional('timeout'): _timeout_schema(),
         Optional('auto_login'): _auto_login_schema(),
         Optional('parameters'): _simple_params(),
     }, extra=True)
@@ -75,7 +95,7 @@ def _inline_schema():
     })
 
 
-def _job_definition_schema():
+def _test_definition_schema():
     return Schema([
         {
             Required('repository'): Any(_inline_schema(), str),
@@ -89,22 +109,23 @@ def _job_definition_schema():
 
 def _job_test_schema():
     return Schema({
-        Required('definitions'): _job_definition_schema(),
-        Optional('timeouts'): _timeout_schema(),
+        Required('definitions'): _test_definition_schema(),
+        Optional('timeout'): _timeout_schema(),
     }, extra=True)
 
 
 def _job_monitor_schema():
     return Schema({
         Required('monitors'): _monitor_def_schema(),
-        Optional('timeouts'): _timeout_schema()
+        Optional('timeout'): _timeout_schema()
     }, extra=True)
 
 
 def _monitor_def_schema():
     return Schema([
         {
-            Required('name'): str,
+            Required('name'): Match(r'^[a-zA-Z0-9-_]+$',
+                                    msg=INVALID_CHARACTER_ERROR_MSG),
             Required('start'): str,
             Required('end'): str,
             Required('pattern'): str,
@@ -113,6 +134,13 @@ def _monitor_def_schema():
     ])
 
 
+def _job_command_schema():
+    return Schema({
+        Required('name'): str,
+        Optional('timeout'): _timeout_schema()
+    })
+
+
 def _job_actions_schema():
     return Schema([
         {
@@ -121,7 +149,8 @@ def _job_actions_schema():
                 _job_deploy_schema()),
             'boot': _job_boot_schema(),
             'test': Any(_job_monitor_schema(),
-                        _job_test_schema())
+                        _job_test_schema()),
+            'command': _job_command_schema()
         }
     ])
 
@@ -130,6 +159,7 @@ def _job_notify_schema():
     return Schema({
         Required('criteria'): _notify_criteria_schema(),
         'recipients': _recipient_schema(),
+        'callback': _callback_schema(),
         'verbosity': Any('verbose', 'quiet', 'status-only'),
         'compare': _notify_compare_schema()
     }, extra=True)
@@ -153,7 +183,8 @@ def _recipient_schema():
 
 def _notify_criteria_schema():
     return Schema({
-        Required('status'): Any('complete', 'incomplete', 'canceled'),
+        Required('status'): Any('running', 'complete', 'incomplete',
+                                'canceled', 'finished'),
         'type': Any('progression', 'regression')
     }, extra=True)
 
@@ -179,6 +210,16 @@ def _query_conditions_schema():
     })
 
 
+def _callback_schema():
+    return Schema({
+        'method': Any('GET', 'POST'),
+        Required('url'): str,
+        'token': str,
+        'dataset': Any('minimal', 'logs', 'results', 'all'),
+        'content-type': Any('json', 'urlencoded')
+    }, extra=True)
+
+
 def vlan_name(value):
     if re.match("^[_a-zA-Z0-9]+$", str(value)):
         return str(value)
@@ -205,17 +246,30 @@ def _job_protocols_schema():
     })
 
 
+def action_name(value):
+    if re.match(r'^[a-z-]+$', str(value)):
+        return str(value)
+    else:
+        raise Invalid(value)
+
+
 def _job_timeout_schema():
     return Schema({
         Required('job'): _timeout_schema(),
-        Required('action'): _timeout_schema(),
-        'connection': _timeout_schema(),
-    }, extra=True)
+        Optional('action'): _timeout_schema(),
+        Optional('connection'): _timeout_schema(),
+        Optional('actions'): {
+            All(action_name): _timeout_schema()
+        },
+        Optional('connections'): {
+            All(action_name): _timeout_schema()
+        },
+    })
 
 
 def visibility_schema():
     # possible values - 1 of 2 strings or a specified dict
-    return Schema(Any('public', 'personal', {'group': str}))
+    return Schema(Any('public', 'personal', {'group': [str]}))
 
 
 def _job_schema():
@@ -223,16 +277,18 @@ def _job_schema():
         {
             'device_type': All(str, Length(min=1)),  # not Required as some protocols encode it elsewhere
             Required('job_name'): All(str, Length(min=1, max=200)),
-            'priority': Any('high', 'medium', 'low'),
-            'protocols': _job_protocols_schema(),
-            'context': _context_schema(),
-            'metadata': dict,
-            'secrets': dict,
-            'tags': [str],
+            Optional('include'): str,
+            Optional('priority'): Any('high', 'medium', 'low'),
+            Optional('protocols'): _job_protocols_schema(),
+            Optional('context'): _context_schema(),
+            Optional('metadata'): All({Any(str, int): Any(str, int)}),
+            Optional('secrets'): dict,
+            Optional('tags'): [str],
             Required('visibility'): visibility_schema(),
             Required('timeouts'): _job_timeout_schema(),
             Required('actions'): _job_actions_schema(),
-            'notify': _job_notify_schema()
+            Optional('notify'): _job_notify_schema(),
+            Optional('reboot_to_fastboot'): bool
         }
     )
 
@@ -261,13 +317,29 @@ def _device_actions_schema():
 
 def _device_timeouts_schema():
     return Schema({
-        'actions': {
-            All(str): _timeout_schema()
+        Optional('actions'): {
+            All(action_name): _timeout_schema()
         },
-        'connections': {
-            All(str): _timeout_schema()
-        },
-    }, extra=True)
+        Optional('connections'): {
+            All(action_name): _timeout_schema()
+        }
+    })
+
+
+def _device_user_commands():
+    return Schema({
+        All(str): {
+            Required('do'): str,
+            Optional('undo'): str
+        }
+    })
+
+
+def _device_commands_schema():
+    return Schema({
+        All(str): Any(list, str),
+        Optional('users'): _device_user_commands()
+    })
 
 
 def _device_schema():
@@ -276,16 +348,24 @@ def _device_schema():
     """
     return Schema({
         'character_delays': dict,
-        'commands': dict,
+        'commands': _device_commands_schema(),
+        'constants': dict,
         'adb_serial_number': str,
         'fastboot_serial_number': str,
+        'fastboot_options': [str],
+        'fastboot_via_uboot': bool,
+        'device_info': [dict],
         'flash_cmds_order': list,
-        'board_id': str,
-        'device_path': [str],
         'device_type': All(str, Length(min=1)),
         'parameters': dict,
+        'board_id': str,
+        'usb_vendor_id': All(str, Length(min=4, max=4)),  # monitor type like arduino
+        'usb_product_id': All(str, Length(min=4, max=4)),  # monitor type like arduino
+        'usb_filesystem_label': str,
+        'usb_serial_driver': str,
         'actions': _device_actions_schema(),
-        'timeouts': _device_timeouts_schema()
+        'timeouts': _device_timeouts_schema(),
+        'available_architectures': list
     })
 
 
@@ -295,6 +375,45 @@ def _validate_secrets(data_object):
             raise SubmissionException("When 'secrets' is used, 'visibility' shouldn't be 'public'")
 
 
+def _download_raw_yaml(url):
+    try:
+        data = yaml.load(
+            urllib2.urlopen(url, timeout=INCLUDE_URL_TIMEOUT).read())
+        return data
+    except urllib2.URLError as e:
+        raise SubmissionException(
+            "Section 'include' must contain valid URL: %s" % e)
+    except yaml.YAMLError as e:
+        raise SubmissionException("Section 'include' must contain URL to a raw file in valid YAML format: %s" % e)
+
+
+def include_yaml(data_object, include_data):
+
+    if not isinstance(include_data, dict):
+        raise SubmissionException("Include section must be a dictionary.")
+
+    for key in include_data:
+        if key not in data_object:
+            data_object[key] = include_data[key]
+        else:
+            if isinstance(data_object[key], dict):
+                data_object[key].update(include_data[key])
+            elif isinstance(data_object[key], list):
+                data_object[key] += include_data[key]
+            elif isinstance(data_object[key], str):
+                data_object[key] = include_data[key]
+
+    return data_object
+
+
+def handle_include_option(data_object):
+    if 'include' in data_object:
+        include_data = _download_raw_yaml(data_object['include'])
+        include_yaml(data_object, include_data)
+
+    return data_object
+
+
 def validate_submission(data_object):
     """
     Validates a python object as a TestJob submission
@@ -302,6 +421,7 @@ def validate_submission(data_object):
     :return: True if valid, else raises SubmissionException
     """
     try:
+        data_object = handle_include_option(data_object)
         schema = _job_schema()
         schema(data_object)
     except MultipleInvalid as exc:
