@@ -3,7 +3,6 @@ import json
 import logging
 from django.template import defaultfilters as filters
 from django.utils.safestring import mark_safe
-from django.utils.html import escape
 import django_tables2 as tables
 from lava_scheduler_app.models import (
     TestJob,
@@ -43,7 +42,6 @@ class RestrictedIDLinkColumn(IDLinkColumn):
 
     def render(self, record, table=None):
         user = table.context.get('request').user
-        device_type = record.job_device_type()
         if record.can_view(user):
             return pklink(record)
         else:
@@ -52,8 +50,6 @@ class RestrictedIDLinkColumn(IDLinkColumn):
 
 def pklink(record):
     job_id = record.pk
-    complete = ''
-    button = ''
     if isinstance(record, TestJob):
         if record.sub_jobs_list:
             job_id = record.sub_id
@@ -152,14 +148,60 @@ class JobTable(LavaTable):
         self.length = 25
 
     id = tables.Column(verbose_name="ID")
-    actions = tables.TemplateColumn(
-        template_name="lava_scheduler_app/job_actions_field.html")
+    actions = tables.TemplateColumn('''{% load utils %}
+
+{% can_view record request.user as can_view %}
+
+<div class="text-nowrap">
+  <a class="btn btn-xs btn-success {% if not can_view %}disabled{% endif %}"
+     title="{% if can_view %}View job results{% else %}Insufficient permissions{% endif %}"
+     {% if not can_view %}
+     onclick="javascript:void(0)" style="pointer-events: auto;"
+     {% else %}
+     href="{{ record.results_link }}"
+     {% endif %}>
+    <span class="glyphicon glyphicon-signal"></span>
+  </a>
+    <a class="btn btn-xs btn-info {% if not can_view %}disabled{% endif %}"
+     title="{% if can_view %}View job details{% else %}Insufficient permissions{% endif %}"
+     {% if not can_view %}
+     onclick="javascript:void(0)" style="pointer-events: auto;"
+     {% else %}
+     href="{{ record.get_absolute_url }}"
+     {% endif %}>
+    <span class="glyphicon glyphicon-eye-open"></span>
+  </a>
+    <a class="btn btn-xs btn-primary {% if not can_view %}disabled{% endif %}" title="{% if can_view %}End of log{% else %}Insufficient permissions{% endif %}"
+     {% if not can_view %}
+     onclick="javascript:void(0)" style="pointer-events: auto;"
+     {% else %}
+     href="{{ record.get_absolute_url }}{% if record.is_pipeline %}#bottom{% else %}/log_file#bottom{% endif %}"
+     {% endif %}>
+    <span class="glyphicon glyphicon-fast-forward"></span>
+  </a>
+</div>''')
     actions.orderable = False
+
     device = tables.Column(accessor='device_sort')
     duration = tables.Column(accessor='duration_sort')
     duration.orderable = False
-    submit_time = tables.DateColumn(format="Nd, g:ia")
-    end_time = tables.DateColumn(format="Nd, g:ia")
+    submit_time = tables.DateColumn(format=u"Nd, g:ia")
+    end_time = tables.DateColumn(format=u"Nd, g:ia")
+
+    def render_status(self, record):
+        text = 'text-default'
+        if record.status == TestJob.COMPLETE:
+            text = 'text-success'
+        elif record.status == TestJob.RUNNING:
+            text = 'text-info'
+        elif record.status == TestJob.INCOMPLETE:
+            text = 'text-danger'
+        elif record.status in [TestJob.CANCELING, TestJob.CANCELED]:
+            text = 'text-warning'
+        elif record.status == TestJob.SUBMITTED:
+            text = 'text-muted'
+        return mark_safe('<span class="%s"><strong>%s</strong></span>' %
+                         (text, TestJob.STATUS_CHOICES[record.status][1]))
 
     def render_device(self, record):
         if record.actual_device:
@@ -175,7 +217,7 @@ class JobTable(LavaTable):
             return 'connection'
         else:
             return '-'
-        if device_type.num_devices_visible_to(self.context.get('request').user) == 0:
+        if not device_type.some_devices_visible_to(self.context.get('request').user):
             return "Unavailable"
         return retval
 
@@ -235,16 +277,12 @@ class JobTable(LavaTable):
         times = {
             'submit_time': 'hours',
             'end_time': 'hours',
-            # 'duration': 'minutes' FIXME: needs a function call
         }
 
 
 class IndexJobTable(JobTable):
 
     id = tables.Column(verbose_name="ID")
-    actions = tables.TemplateColumn(
-        template_name="lava_scheduler_app/job_actions_field.html")
-    actions.orderable = False
     device = tables.Column(accessor='device_sort')
     submit_time = tables.DateColumn("Nd, g:ia")
     end_time = tables.DateColumn("Nd, g:ia")
@@ -254,14 +292,8 @@ class IndexJobTable(JobTable):
         self.length = 25
 
     class Meta(JobTable.Meta):  # pylint: disable=too-few-public-methods,no-init,no-self-use
-        fields = (
-            'id', 'actions', 'status', 'priority', 'device',
-            'description', 'submitter', 'submit_time'
-        )
-        sequence = (
-            'id', 'actions', 'status', 'priority', 'device',
-            'description', 'submitter', 'submit_time'
-        )
+        fields = ()
+        sequence = ('...',)
         exclude = ('end_time', 'duration', )
 
 
@@ -274,16 +306,13 @@ class TagsColumn(tables.Column):
         if len(values) > 0:
             tags = '<p class="collapse" id="%s">' % tag_id
             tags += ',<br>'.join('<abbr data-toggle="tooltip" title="%s">%s</abbr>' % (tag.description, tag.name) for tag in values)
-            tags += '</p><p><a class="btn btn-xs btn-success" data-toggle="collapse" data-target="#%s"><span class="glyphicon glyphicon-eye-open"></span></p></a></p>' % tag_id
+            tags += '</p><a class="btn btn-xs btn-success" data-toggle="collapse" data-target="#%s"><span class="glyphicon glyphicon-eye-open"></span></a>' % tag_id
         return mark_safe(tags)
 
 
 class FailedJobTable(JobTable):
 
     id = tables.Column(verbose_name="ID")
-    actions = tables.TemplateColumn(
-        template_name="lava_scheduler_app/job_actions_field.html")
-    actions.orderable = False
     device = tables.Column(accessor='device_sort')
     duration = tables.Column(accessor='duration_sort')
     duration.orderable = False
@@ -297,12 +326,8 @@ class FailedJobTable(JobTable):
         self.length = 10
 
     class Meta(JobTable.Meta):  # pylint: disable=too-few-public-methods,no-init,no-self-use
-        fields = (
-            'id', 'actions', 'status', 'device', 'submit_time'
-        )
-        sequence = (
-            'id', 'actions', 'status', 'device', 'submit_time'
-        )
+        fields = ()
+        sequence = ('...',)
         exclude = ('submitter', 'end_time', 'priority', 'description')
 
 
@@ -310,9 +335,6 @@ class LongestJobTable(JobTable):
 
     id = tables.Column(verbose_name="ID")
     id.orderable = False
-    actions = tables.TemplateColumn(
-        template_name="lava_scheduler_app/job_actions_field.html")
-    actions.orderable = False
     status = tables.Column()
     status.orderable = False
     device = tables.Column(accessor='actual_device')
@@ -345,12 +367,8 @@ class LongestJobTable(JobTable):
         return ''
 
     class Meta(JobTable.Meta):  # pylint: disable=too-few-public-methods,no-init,no-self-use
-        fields = (
-            'id', 'actions', 'status', 'device'
-        )
-        sequence = (
-            'id', 'actions', 'status', 'device'
-        )
+        fields = ()
+        sequence = ('...',)
         exclude = ('duration', 'end_time')
 
 
@@ -358,9 +376,6 @@ class OverviewJobsTable(JobTable):
 
     id = tables.Column(verbose_name="ID")
     id.orderable = False
-    actions = tables.TemplateColumn(
-        template_name="lava_scheduler_app/job_actions_field.html")
-    actions.orderable = False
     device = tables.Column(accessor='device_sort')
     duration = tables.Column(accessor='duration_sort')
     duration.orderable = False
@@ -372,23 +387,14 @@ class OverviewJobsTable(JobTable):
         self.length = 10
 
     class Meta(JobTable.Meta):  # pylint: disable=too-few-public-methods,no-init,no-self-use
-        fields = (
-            'id', 'actions', 'status', 'priority', 'device',
-            'description', 'submitter', 'submit_time', 'end_time',
-            'duration'
-        )
-        sequence = (
-            'id', 'actions'
-        )
+        fields = ()
+        sequence = ('...',)
 
 
 class RecentJobsTable(JobTable):
 
     id = tables.Column(verbose_name="ID")
     id.orderable = False
-    actions = tables.TemplateColumn(
-        template_name="lava_scheduler_app/job_actions_field.html")
-    actions.orderable = False
     device = tables.Column(accessor='device_sort')
     log_level = tables.Column(accessor="definition", verbose_name="Log level")
     duration = tables.Column(accessor='duration_sort')
@@ -412,15 +418,9 @@ class RecentJobsTable(JobTable):
         return data['logging_level'].lower()
 
     class Meta(JobTable.Meta):  # pylint: disable=too-few-public-methods,no-init,no-self-use
-        fields = (
-            'id', 'actions', 'status', 'priority',
-            'description', 'submitter', 'submit_time', 'end_time',
-            'duration'
-        )
+        fields = ()
         sequence = (
-            'id', 'actions', 'status', 'priority',
-            'description', 'submitter', 'submit_time', 'end_time',
-            'duration', 'log_level'
+            '...', 'log_level'
         )
         exclude = ('device',)
 
@@ -509,8 +509,8 @@ class DeviceTypeTable(LavaTable):
     class Meta(LavaTable.Meta):  # pylint: disable=too-few-public-methods,no-init,no-self-use
         model = DeviceType
         exclude = [
-            'display', 'health_check_job', 'owners_only', 'architecture',
-            'health_denominator', 'health_frequency',
+            'display', 'disable_health_check', 'health_check_job', 'owners_only',
+            'architecture', 'health_denominator', 'health_frequency',
             'processor', 'cpu_model', 'bits', 'cores', 'core_count', 'description'
         ]
         searches = {
@@ -692,9 +692,6 @@ class QueueJobsTable(JobTable):
 
     id = tables.Column(verbose_name="ID")
     id.orderable = False
-    actions = tables.TemplateColumn(
-        template_name="lava_scheduler_app/job_actions_field.html")
-    actions.orderable = False
     device = tables.Column(accessor='device_sort')
     in_queue = tables.TemplateColumn('''
     for {{ record.submit_time|timesince }}
@@ -708,14 +705,8 @@ class QueueJobsTable(JobTable):
         self.length = 50
 
     class Meta(JobTable.Meta):  # pylint: disable=too-few-public-methods,no-init,no-self-use
-        fields = (
-            'id', 'actions', 'device', 'description', 'submitter',
-            'submit_time', 'in_queue'
-        )
-        sequence = (
-            'id', 'actions', 'device', 'description', 'submitter',
-            'submit_time', 'in_queue'
-        )
+        fields = ()
+        sequence = ('...',)
         exclude = ('status', 'priority', 'end_time', 'duration')
 
 
@@ -816,7 +807,7 @@ class RunningTable(LavaTable):
         super(RunningTable, self).__init__(*args, **kwargs)
         self.length = 50
 
-    # FIXME: dynamic connections are TestJob without a device, add extra column
+    # deprecated: dynamic connections are TestJob without a device
 
     def render_jobs(self, record):  # pylint: disable=no-self-use
         count = TestJob.objects.filter(
@@ -847,6 +838,6 @@ class RunningTable(LavaTable):
             'name', 'reserved', 'running', 'jobs'
         ]
         exclude = [
-            'display', 'health_check_job', 'owners_only', 'architecture',
+            'display', 'disable_health_check', 'health_check_job', 'owners_only', 'architecture',
             'processor', 'cpu_model', 'bits', 'cores', 'core_count', 'description'
         ]
