@@ -2,6 +2,7 @@
 import logging
 import sys
 import warnings
+import yaml
 from dashboard_app.models import BundleStream
 
 from django.contrib.auth.models import Group, Permission, User
@@ -13,11 +14,12 @@ from lava_scheduler_app.models import (
     Device,
     DeviceType,
     JSONDataError,
+    Notification,
     Tag,
     TestJob,
     DevicesUnavailableException,
-    DeviceDictionary,
     _check_exclusivity,
+    is_deprecated_json,
 )
 import simplejson
 
@@ -28,6 +30,7 @@ LOGGER.addHandler(logging.StreamHandler(sys.stdout))
 warnings.filterwarnings('ignore', r"Using mimetype keyword argument is deprecated")
 warnings.filterwarnings('ignore', r"StrAndUnicode is deprecated")
 
+
 # pylint gets confused with TestCase
 # pylint: disable=no-self-use,invalid-name,too-many-ancestors,too-many-public-methods
 
@@ -52,7 +55,6 @@ class ModelFactory(object):
         # make sure the DB is in a clean state wrt devices and jobs
         Device.objects.all().delete()
         TestJob.objects.all().delete()
-        [item.delete() for item in DeviceDictionary.object_list()]  # pylint: disable=expression-not-assigned
         User.objects.all().delete()
         Group.objects.all().delete()
 
@@ -83,22 +85,20 @@ class ModelFactory(object):
         self.make_device(device_type)
         return device_type
 
-    def make_device_type(self, name=None, health_check_job=None):
+    def make_device_type(self, name=None):
         if name is None:
             name = self.getUniqueString('name')
-        device_type, created = DeviceType.objects.get_or_create(
-            name=name, health_check_job=health_check_job)
+        device_type, created = DeviceType.objects.get_or_create(name=name)
         if created:
             device_type.save()
         logging.debug("asking for a device of type %s", device_type.name)
         return device_type
 
-    def make_hidden_device_type(self, name=None, health_check_job=None):
+    def make_hidden_device_type(self, name=None):
         if name is None:
             name = self.getUniqueString('name')
         device_type, created = DeviceType.objects.get_or_create(
-            owners_only=True,
-            name=name, health_check_job=health_check_job)
+            owners_only=True, name=name)
         if created:
             device_type.save()
         logging.debug("asking for a device of type %s", device_type.name)
@@ -139,9 +139,16 @@ class ModelFactory(object):
     def make_job_json(self, **kw):
         return simplejson.dumps(self.make_job_data(**kw), sort_keys=True, indent=4 * ' ')
 
+    def make_invalid_job_json(self, **kw):
+        actions = [{'command': 'invalid_command'}]
+        return simplejson.dumps(self.make_job_data(actions, **kw), sort_keys=True, indent=4 * ' ')
+
+    def make_job_yaml(self, **kw):
+        return yaml.dump(self.make_job_data(**kw))
+
     def make_testjob(self, definition=None, submitter=None, **kwargs):
         if definition is None:
-            definition = self.make_job_json()
+            definition = self.make_job_json(**kwargs)
         if submitter is None:
             submitter = self.make_user()
         if 'user' not in kwargs:
@@ -150,6 +157,19 @@ class ModelFactory(object):
         testjob.save()
         return testjob
 
+    def make_notification(self, job):
+        notification = Notification()
+        notification.test_job = job
+        notification.verbosity = Notification.QUIET
+
+        notification.callback_url = "http://localhost/"
+        notification.callback_token = "token"
+        notification.callback_method = Notification.POST
+        notification.callback_dataset = Notification.MINIMAL
+        notification.save()
+
+        return notification
+
 
 class TestCaseWithFactory(TestCase):  # pylint: disable=too-many-ancestors
 
@@ -166,6 +186,15 @@ class TestTestJob(TestCaseWithFactory):  # pylint: disable=too-many-ancestors,to
         self.assertEqual(definition, job.definition)
         self.factory.cleanup()
 
+    def test_from_json_and_user_sets_outputdir(self):
+        definition = self.factory.make_job_json()
+        job = TestJob.from_json_and_user(definition, self.factory.make_user())
+        dir_list = job.output_dir.split('/')
+        self.assertIn("%02d" % job.submit_time.year, dir_list)
+        self.assertIn("%02d" % job.submit_time.month, dir_list)
+        self.assertIn("%02d" % job.submit_time.day, dir_list)
+        self.assertIn(str(job.id), dir_list)
+
     def test_user_permission(self):
         self.assertIn(
             'cancel_resubmit_testjob',
@@ -206,18 +235,18 @@ class TestTestJob(TestCaseWithFactory):  # pylint: disable=too-many-ancestors,to
         self.factory.cleanup()
 
     def test_from_json_and_user_sets_target(self):
-        panda_board = self.factory.make_device(hostname='panda01')
+        panda_board = self.factory.make_device(hostname='panda02')
         job = TestJob.from_json_and_user(
-            self.factory.make_job_json(target='panda01'),
+            self.factory.make_job_json(target='panda02'),
             self.factory.make_user())
         self.assertEqual(panda_board, job.requested_device)
         self.factory.cleanup()
 
     def test_from_json_and_user_does_not_set_device_type_from_target(self):
         panda_type = self.factory.ensure_device_type(name='panda')
-        self.factory.make_device(device_type=panda_type, hostname='panda01')
+        self.factory.make_device(device_type=panda_type, hostname='panda02')
         job = TestJob.from_json_and_user(
-            self.factory.make_job_json(target='panda01'),
+            self.factory.make_job_json(target='panda02'),
             self.factory.make_user())
         self.assertEqual(None, job.requested_device_type)
         self.factory.cleanup()
@@ -358,17 +387,11 @@ class TestTestJob(TestCaseWithFactory):  # pylint: disable=too-many-ancestors,to
 
     def test_from_json_rejects_exclusive(self):
         panda_type = self.factory.ensure_device_type(name='panda')
-        panda_board = self.factory.make_device(device_type=panda_type, hostname='panda01')
-        self.assertFalse(panda_board.is_exclusive)
+        panda_board = self.factory.make_device(device_type=panda_type, hostname='panda03')
         job = TestJob.from_json_and_user(
             self.factory.make_job_json(device_type='panda'),
             self.factory.make_user())
         self.assertEqual(panda_type, job.requested_device_type)
-        device_dict = DeviceDictionary.get(panda_board.hostname)
-        self.assertIsNone(device_dict)
-        device_dict = DeviceDictionary(hostname=panda_board.hostname)
-        device_dict.parameters = {'exclusive': 'True'}
-        device_dict.save()
         self.assertTrue(panda_board.is_exclusive)
         self.assertRaises(
             DevicesUnavailableException, _check_exclusivity, [panda_board], pipeline=False
@@ -689,6 +712,42 @@ class TestTestJob(TestCaseWithFactory):  # pylint: disable=too-many-ancestors,to
             self.factory.make_user())
         self.factory.cleanup()
 
+    def test_is_deprecated_json(self):
+        self.assertTrue(is_deprecated_json(self.factory.make_job_json()))
+        self.assertFalse(is_deprecated_json(self.factory.make_job_yaml()))
+
+        invalid_job_data = self.factory.make_invalid_job_json()
+        self.assertFalse(is_deprecated_json(invalid_job_data))
+
+    def test_get_callback_data(self):
+
+        device_type = self.factory.ensure_device_type(name='panda')
+        self.factory.make_device(device_type=device_type, hostname="panda3")
+        user = self.factory.ensure_user(username='notification-user', email='', password='test', )
+        job = self.factory.make_testjob(device_type='panda', submitter=user)
+        notification = self.factory.make_notification(job)
+
+        test_callback_data = {
+            'actual_device_id': None,
+            'definition': '{\n    "actions": [],\n    "device_type": "panda",\n    "health_check": false,\n    "timeout": 1\n}',
+            'description': '',
+            'end_time': 'None',
+            'failure_comment': None,
+            'is_pipeline': False,
+            'metadata': [],
+            'priority': 50,
+            'start_time': 'None',
+            'status': 0,
+            'status_string': 'submitted',
+            'submitter_username': u'notification-user',
+            'token': 'token'
+        }
+        notification_callback_data = notification.get_callback_data()
+        del notification_callback_data['submit_time']
+        del notification_callback_data['id']
+
+        self.assertEqual(test_callback_data, notification_callback_data)
+
 
 class TestHiddenTestJob(TestCaseWithFactory):  # pylint: disable=too-many-ancestors
 
