@@ -1,20 +1,23 @@
 from django.conf.urls import url
 from lava_scheduler_app.views import (
     active_device_list, active_jobs, device_derestrict_device, device_detail,
-    device_edit_description, device_force_health_check, device_health_history_log,
-    device_list, device_looping_mode, device_maintenance_mode, device_online,
-    device_reports, device_restrict_device, device_type_detail, device_dictionary,
-    device_type_health_history_log, device_type_reports, edit_transition, edit_worker_desc,
-    expanded_job_definition, failure_report, favorite_jobs, get_remote_definition,
-    health_job_list, healthcheck, index, job_annotate_failure, job_cancel, job_change_priority,
-    job_complete_log, job_definition, job_definition_plain, job_description_yaml,
-    job_detail, job_full_log_incremental, job_json, job_list, job_log_file, job_log_file_plain,
-    job_log_incremental, job_log_pipeline_incremental, job_output,
-    job_pipeline_incremental, job_pipeline_sections, job_pipeline_timing,
-    job_resubmit, job_section_log, job_status, job_submit, job_submit_wizard,
-    job_toggle_favorite, lab_health, longest_jobs, multinode_job_definition,
-    multinode_job_definition_plain, mydevice_list,
-    mydevices_health_history_log, myjobs, online_device_list,
+    device_edit_description, device_force_health_check,
+    device_health_history_log, device_list, device_looping_mode,
+    device_maintenance_mode, device_online, device_reports,
+    device_restrict_device, device_type_detail, device_dictionary,
+    device_dictionary_plain, device_type_health_history_log,
+    device_type_reports, edit_transition, edit_worker_desc,
+    expanded_job_definition, failure_report, favorite_jobs,
+    get_remote_definition, health_job_list, healthcheck, index,
+    job_annotate_failure, job_cancel, job_change_priority, job_complete_log,
+    job_definition, job_definition_plain, job_description_yaml, job_detail,
+    job_full_log_incremental, job_json, job_list, job_log_file,
+    job_log_file_plain, job_log_incremental, job_log_pipeline_incremental,
+    job_output, job_pipeline_incremental, job_pipeline_sections,
+    job_pipeline_timing, job_resubmit, job_section_log, job_status,
+    job_submit, job_submit_wizard, job_toggle_favorite, lab_health, migration,
+    longest_jobs, multinode_job_definition, multinode_job_definition_plain,
+    mydevice_list, mydevices_health_history_log, myjobs, online_device_list,
     passing_health_checks, pipeline, pipeline_device_list, queue, reports,
     running, transition_detail, username_list_json, vmgroup_job_definition,
     vmgroup_job_definition_plain, worker_detail, workers,
@@ -37,6 +40,9 @@ urlpatterns = [
         name='lava.scheduler.device.detail'),
     url(r'^device/(?P<pk>[-_a-zA-Z0-9.]+)/devicedict$', device_dictionary,
         name='lava.scheduler.device.dictionary'),
+    url(r'^device/(?P<pk>[-_a-zA-Z0-9.]+)/devicedict/plain$',
+        device_dictionary_plain,
+        name='lava.scheduler.device.dictionary.plain'),
     url(r'^allworkers$', workers, name='lava.scheduler.workers'),
     url(r'^worker/(?P<pk>[-_a-zA-Z0-9.]+)$', worker_detail,
         name='lava.scheduler.worker.detail'),
@@ -172,4 +178,5 @@ urlpatterns = [
         name='lava_scheduler_download_device_type_yaml'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+.[0-9]+)/similarjobs$', similar_jobs,
         name='lava.scheduler.job.similar_jobs'),
+    url(r'^migration$', migration, name='lava.scheduler.migration'),
 ]
