@@ -33,7 +33,7 @@ import imp
 
 # Check for available modules
 available_modules = list()
-for module_name in ["devserver", "django_extensions", "django_openid_auth", "hijack"]:
+for module_name in ["devserver", "django_extensions", "hijack"]:
     try:
         imp.find_module(module_name)
         available_modules.append(module_name)
@@ -66,6 +66,7 @@ TEMPLATES = [
                 "django.template.context_processors.debug",
                 "django.template.context_processors.request",
                 "django.contrib.auth.context_processors.auth",
+                "django.contrib.messages.context_processors.messages",
                 "django.template.context_processors.i18n",
                 "django.template.context_processors.static",
                 # LAVA context processors
@@ -86,6 +87,8 @@ MIDDLEWARE_CLASSES = [
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
+    'django.middleware.security.SecurityMiddleware',
+    'django.middleware.clickjacking.XFrameOptionsMiddleware',
 ]
 
 ROOT_URLCONF = 'lava_server.urls'
@@ -111,11 +114,13 @@ INSTALLED_APPS = [
     'django.contrib.sessions',
     'django.contrib.sites',
     'django.contrib.humanize',
+    'django.contrib.messages',
     'django.contrib.staticfiles',
     'django.contrib.admin',
     # Uncomment the next line to enable admin documentation:
     # 'django.contrib.admindocs',
     # Add LAVA applications
+    'lava_server',
     'dashboard_app',
     'lava_results_app',
     'lava_scheduler_daemon',
@@ -133,21 +138,6 @@ TEST_RUNNER = 'django.test.runner.DiscoverRunner'
 
 AUTHENTICATION_BACKENDS = ['django.contrib.auth.backends.ModelBackend']
 
-if "django_openid_auth" in available_modules:
-    AUTHENTICATION_BACKENDS.append('django_openid_auth.auth.OpenIDBackend')
-    MIGRATION_MODULES = {
-        'django_openid_auth': 'django_openid_auth.migrations'
-    }
-
-    OPENID_CREATE_USERS = True
-    OPENID_LAUNCHPAD_TEAMS_MAPPING_AUTO = False
-    OPENID_UPDATE_DETAILS_FROM_SREG = True
-    OPENID_SSO_SERVER_URL = 'https://login.ubuntu.com/'
-
-    # python-openid is too noisy, so we silence it.
-    from openid import oidutil
-    oidutil.log = lambda msg, level=0: None
-
 # Add google analytics model.
 GOOGLE_ANALYTICS_MODEL = True
 
@@ -155,3 +145,18 @@ ALLOWED_HOSTS = ['*']
 
 # this is a tad ugly but the upstream package still needs something here.
 KEY_VALUE_STORE_BACKEND = 'db://lava_scheduler_app_devicedictionarytable'
+
+# Django System check framework settings for security.* checks.
+# Silence some checks that should be explicitly configured by administrators
+# on need basis.
+SILENCED_SYSTEM_CHECKS = [
+    'security.W004',  # silence SECURE_HSTS_SECONDS
+    'security.W008',  # silence SECURE_SSL_REDIRECT
+]
+SECURE_CONTENT_TYPE_NOSNIFF = True
+SECURE_BROWSER_XSS_FILTER = True
+SESSION_COOKIE_SECURE = True
+CSRF_COOKIE_SECURE = True
+CSRF_COOKIE_HTTPONLY = True
+X_FRAME_OPTIONS = 'DENY'
+HTTPS_XML_RPC = True
