@@ -68,24 +68,6 @@ LOGIN_REDIRECT_URL = distro_settings.LOGIN_REDIRECT_URL
 if distro_settings.get_setting("SERVER_EMAIL"):
     SERVER_EMAIL = distro_settings.get_setting("SERVER_EMAIL")
 
-# Atlassian Crowd authentication config
-AUTH_CROWD_SERVER_REST_URI = distro_settings.get_setting("AUTH_CROWD_SERVER_REST_URI")
-if AUTH_CROWD_SERVER_REST_URI:
-    # If Crowd server URL is configured, disable OpenID and
-    # enable Crowd auth backend
-    INSTALLED_APPS.append('crowdrest')
-    AUTHENTICATION_BACKENDS = ['crowdrest.backend.CrowdRestBackend'] + \
-        [x for x in AUTHENTICATION_BACKENDS if "OpenID" not in x]
-
-    # Load credentials from a separate file
-    from lava_server.settings.config_file import ConfigFile
-    pathname = distro_settings._get_pathname("crowd")
-    crowd_config = ConfigFile.load(pathname)
-    AUTH_CROWD_APPLICATION_USER = crowd_config.AUTH_CROWD_APPLICATION_USER
-    AUTH_CROWD_APPLICATION_PASSWORD = crowd_config.AUTH_CROWD_APPLICATION_PASSWORD
-    if distro_settings.get_setting("AUTH_CROWD_GROUP_MAP"):
-        AUTH_CROWD_GROUP_MAP = distro_settings.get_setting("AUTH_CROWD_GROUP_MAP")
-
 AUTH_DEBIAN_SSO = distro_settings.get_setting("AUTH_DEBIAN_SSO")
 
 # LDAP authentication config
@@ -154,6 +136,7 @@ USE_DEBUG_TOOLBAR = distro_settings.get_setting('USE_DEBUG_TOOLBAR', False)
 
 if USE_DEBUG_TOOLBAR:
     INSTALLED_APPS.append('debug_toolbar')
+    MIDDLEWARE_CLASSES = ['debug_toolbar.middleware.DebugToolbarMiddleware'] + MIDDLEWARE_CLASSES
     default_ips = ['127.0.0.1', '::1']
     default_ips.extend(distro_settings.get_setting('INTERNAL_IPS', []))
     INTERNAL_IPS = default_ips
@@ -171,6 +154,7 @@ BRANDING_HEIGHT = distro_settings.get_setting("BRANDING_HEIGHT", 22)
 BRANDING_WIDTH = distro_settings.get_setting("BRANDING_WIDTH", 22)
 BRANDING_BUG_URL = distro_settings.get_setting("BRANDING_BUG_URL", "https://bugs.linaro.org/enter_bug.cgi?product=LAVA%20Framework")
 BRANDING_SOURCE_URL = distro_settings.get_setting("BRANDING_SOURCE_URL", "https://git.linaro.org/gitweb?s=lava%2Flava")
+BRANDING_MESSAGE = distro_settings.get_setting("BRANDING_MESSAGE", '')
 
 HIDE_V1_DOCS = distro_settings.get_setting("HIDE_V1_DOCS", False)
 HIDE_V2_DOCS = distro_settings.get_setting("HIDE_V2_DOCS", False)
@@ -252,9 +236,31 @@ EVENT_SOCKET = distro_settings.get_setting("EVENT_SOCKET", EVENT_SOCKET)
 EVENT_ADDITIONAL_SOCKETS = distro_settings.get_setting("EVENT_ADDITIONAL_SOCKETS", EVENT_ADDITIONAL_SOCKETS)
 EVENT_TOPIC = distro_settings.get_setting("EVENT_TOPIC", EVENT_TOPIC)
 
+# Add template caching
+if distro_settings.get_setting("USE_TEMPLATE_CACHE", False):
+    TEMPLATES[0]['OPTIONS']['loaders'] = [('django.template.loaders.cached.Loader',
+                                           TEMPLATES[0]['OPTIONS']['loaders'])]
+
 
 def set_timeout(connection, **kw):
     connection.cursor().execute("SET statement_timeout to 30000")
 
 
 connection_created.connect(set_timeout)
+
+# Allow Django System check framework settings override
+SILENCED_SYSTEM_CHECKS = distro_settings.get_setting("SILENCED_SYSTEM_CHECKS",
+                                                     SILENCED_SYSTEM_CHECKS)
+SECURE_CONTENT_TYPE_NOSNIFF = distro_settings.get_setting(
+    "SECURE_CONTENT_TYPE_NOSNIFF", SECURE_CONTENT_TYPE_NOSNIFF)
+SECURE_BROWSER_XSS_FILTER = distro_settings.get_setting(
+    "SECURE_BROWSER_XSS_FILTER", SECURE_BROWSER_XSS_FILTER)
+SESSION_COOKIE_SECURE = distro_settings.get_setting("SESSION_COOKIE_SECURE",
+                                                    SESSION_COOKIE_SECURE)
+CSRF_COOKIE_SECURE = distro_settings.get_setting("CSRF_COOKIE_SECURE",
+                                                 CSRF_COOKIE_SECURE)
+CSRF_COOKIE_HTTPONLY = distro_settings.get_setting("CSRF_COOKIE_HTTPONLY",
+                                                   CSRF_COOKIE_HTTPONLY)
+X_FRAME_OPTIONS = distro_settings.get_setting("X_FRAME_OPTIONS",
+                                              X_FRAME_OPTIONS)
+HTTPS_XML_RPC = distro_settings.get_setting("HTTPS_XML_RPC", HTTPS_XML_RPC)
