@@ -21,7 +21,6 @@ from django.views.generic import TemplateView
 from django.conf import settings
 from django.conf.urls import include, url
 from django.contrib import admin
-from linaro_django_xmlrpc import urls as api_urls
 from linaro_django_xmlrpc.views import handler as linaro_django_xmlrpc_views_handler
 from linaro_django_xmlrpc.views import help as linaro_django_xmlrpc_views_help
 from django.views.i18n import javascript_catalog
@@ -29,6 +28,12 @@ from django.views.i18n import javascript_catalog
 from dashboard_app.xmlrpc import DashboardAPI
 from lava_results_app.xmlrpc import ResultsAPI
 from lava_scheduler_app.api import SchedulerAPI
+from lava_scheduler_app.api.aliases import SchedulerAliasesAPI
+from lava_scheduler_app.api.devices import SchedulerDevicesAPI, SchedulerDevicesTagsAPI
+from lava_scheduler_app.api.device_types import SchedulerDeviceTypesAPI, SchedulerDeviceTypesAliasesAPI
+from lava_scheduler_app.api.jobs import SchedulerJobsAPI
+from lava_scheduler_app.api.tags import SchedulerTagsAPI
+from lava_scheduler_app.api.workers import SchedulerWorkersAPI
 
 from lava_server.views import index, me, update_irc_settings
 from lava_server.xmlrpc import LavaMapper
@@ -45,6 +50,14 @@ mapper.register_introspection_methods()
 mapper.register(DashboardAPI, 'dashboard')
 mapper.register(ResultsAPI, 'results')
 mapper.register(SchedulerAPI, 'scheduler')
+mapper.register(SchedulerAliasesAPI, 'scheduler.aliases')
+mapper.register(SchedulerDevicesAPI, 'scheduler.devices')
+mapper.register(SchedulerDevicesTagsAPI, 'scheduler.devices.tags')
+mapper.register(SchedulerDeviceTypesAPI, 'scheduler.device_types')
+mapper.register(SchedulerDeviceTypesAliasesAPI, 'scheduler.device_types.aliases')
+mapper.register(SchedulerJobsAPI, 'scheduler.jobs')
+mapper.register(SchedulerTagsAPI, 'scheduler.tags')
+mapper.register(SchedulerWorkersAPI, 'scheduler.workers')
 
 
 # Root URL patterns
@@ -67,43 +80,35 @@ urlpatterns = [
     url(r'^admin/jsi18n', javascript_catalog),
     url(r'^{mount_point}admin/'.format(mount_point=settings.MOUNT_POINT),
         include(admin.site.urls)),
+
+    # RPC endpoints
     url(r'^{mount_point}RPC2/?'.format(mount_point=settings.MOUNT_POINT),
         linaro_django_xmlrpc_views_handler,
         name='lava.api_handler',
-        kwargs={
-            'mapper': mapper,
-            'help_view': 'lava.api_help'}),
+        kwargs={'mapper': mapper,
+                'help_view': 'lava.api_help'}),
     url(r'^{mount_point}api/help/$'.format(mount_point=settings.MOUNT_POINT),
         linaro_django_xmlrpc_views_help,
         name='lava.api_help',
-        kwargs={
-            'mapper': mapper}),
-    url(r'^{mount_point}api/'.format(mount_point=settings.MOUNT_POINT),
-        include(api_urls.token_urlpatterns)),
-    # XXX: This is not needed but without it linaro-django-xmlrpc tests fail
-    url(r'^{mount_point}api/'.format(mount_point=settings.MOUNT_POINT),
-        include(api_urls.default_mapper_urlpatterns)),
+        kwargs={'mapper': mapper}),
 
     url(r'^{mount_point}dashboard/'.format(mount_point=settings.MOUNT_POINT),
         include('dashboard_app.urls')),
+    url(r'^{mount_point}api/'.format(mount_point=settings.MOUNT_POINT),
+        include('linaro_django_xmlrpc.urls')),
     url(r'^{mount_point}results/'.format(mount_point=settings.MOUNT_POINT),
         include('lava_results_app.urls')),
     url(r'^{mount_point}scheduler/'.format(mount_point=settings.MOUNT_POINT),
         include('lava_scheduler_app.urls')),
 ]
 
+if settings.USE_DEBUG_TOOLBAR:
+    import debug_toolbar
+    urlpatterns.append(url(r'^__debug__/', include(debug_toolbar.urls)))
+
 try:
     import hijack
     from hijack.urls import urlpatterns as hijack_urlpatterns
     urlpatterns.append(url(r'^hijack/', include(hijack_urlpatterns)))
 except ImportError:
     pass
-
-try:
-    imp.find_module('django_openid_auth')
-    urlpatterns.append(
-        url(r'^{mount_point}openid/'.format(mount_point=settings.MOUNT_POINT),
-            include('django_openid_auth.urls')),
-    )
-except ImportError:
-    pass
